.. :changelog:

History
-------

1.0.1 (2014-04-17)
++++++++++++++++++
* Major bug fixed on `inbox_get()` backend api
* Fixed InboxSerializer for redis backend messages
* Enhanced testsuite
* Added MessageDoesNotExist descriptions and return 404

1.0.0 (2014-04-01)
++++++++++++++++++
* New backend architecture with Redis support
* Support for broadcast messages

0.2.1 (2013-12-23)
++++++++++++++++++
* Added `stored_messages_count` template tag and tests

0.2.0 (2013-10-22)
++++++++++++++++++

* Added `stored_messages_archive` template tag
* Extended REST api

0.1.2 (2013-10-13)
++++++++++++++++++

* Added specific template tags for stored messages

0.1.1 (2013-10-10)
++++++++++++++++++

* Fixed setup.py

0.1.0 (2013-10-08)
++++++++++++++++++

* First release on PyPI.